/// <reference types="node" />
import $fs from 'fs';
import { URL } from 'url';
export declare const Constants: typeof $fs.constants;
export declare type PathLike = $fs.PathLike | string;
export interface Descriptor {
    path: string;
    stats: $fs.Stats;
}
export declare class FileSystem {
    private readonly fs;
    constructor(fs: any);
    append(path: string | number | Buffer | URL, data: any, throws?: boolean): Promise<boolean>;
    basename(path: string, ext?: string | boolean): string;
    chmod(path: PathLike, mode: number | string): Promise<void>;
    close(fd: number, throws?: boolean): Promise<boolean>;
    delete(path: PathLike, throws?: boolean): Promise<boolean>;
    dirname(filepath: string): string;
    exists(path: PathLike, throws?: boolean, mode?: number): Promise<boolean>;
    ext(filename: string): string;
    file(path: string, content: string, throws?: boolean): Promise<boolean>;
    glob(pattern: string, cwd?: string): Promise<string[]>;
    globs(patterns: string[], cwd?: string): Promise<string[]>;
    list(path: PathLike): Promise<string[]>;
    info(path: PathLike): Promise<Descriptor>;
    join(...paths: string[]): string;
    json<T>(path: string | number | Buffer | URL): Promise<T>;
    mkdir(path: PathLike, mode?: number | string, throws?: boolean): Promise<boolean>;
    mkdirs(paths: string[], mode?: number | string, throws?: boolean): Promise<boolean>;
    mkdirp(path: string, throws?: boolean): Promise<string | undefined>;
    mkdirps(paths: string[], throws?: boolean): Promise<Array<string | undefined>>;
    open(path: PathLike, flags: string | number, mode?: string | number): Promise<number>;
    read<T extends Buffer | Uint8Array>(fd: number, buffer: T, offset: number, length: number, position: number): Promise<number>;
    readFile(path: string | number | Buffer | URL): Promise<Buffer>;
    relative(from: string, to: string): string;
    relativeFrom(to: string): string;
    rename(original: PathLike, filename: PathLike, throws?: boolean): Promise<boolean>;
    resolve(...paths: string[]): string;
    save<T>(path: string, object: T, throws?: boolean): Promise<boolean>;
    stat(path: PathLike): Promise<Descriptor>;
    stats(...paths: PathLike[]): Promise<Descriptor[]>;
    text(path: string | number | Buffer | URL): Promise<string>;
    write<T extends Buffer | Uint8Array>(fd: number, buffer: T, offset?: number, length?: number, position?: number): Promise<number>;
    writeFile(path: string | number | Buffer | URL, data: any): Promise<void>;
}
export declare const fs: FileSystem;
//# sourceMappingURL=FileSystem.d.ts.map